nickva opened a new pull request, #6209: URL: https://github.com/apache/couchdb/pull/6209
Same idea as in #6206: when we read docs from the source use the new `read_doc_bodies/2` batched call. `read_doc_bodies/2` will then use a single preads call for couch_file. Use separate batching parameters (doc count and size) vs the exisiting buffering ones. Those were for target commit scheduling and this is for source batching so it didn't feel like combining the two made sense. Trying to split 1GB Q=1 shard on my mac got a bit of speed-up 1.2x: 94sec -> 75sec. -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected]
